[![Build Status](https://travis-ci.org/jelmer/python-fastimport.png?branch=master)](https://travis-ci.org/jelmer/python-fastimport)

python-fastimport
=================

This package provides a parser for and generator of the Git fastimport format.
(https://www.kernel.org/pub/software/scm/git/docs/git-fast-import.html)
